"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var Molecule_1 = require("../Molecule");
var Agent_1 = require("../Agent");
var mocha_1 = require("mocha");
var chai_1 = require("chai");
mocha_1.describe('Agent', function () {
    var MyAgent = (function (_super) {
        __extends(MyAgent, _super);
        function MyAgent() {
            return _super !== null && _super.apply(this, arguments) || this;
        }
        MyAgent.prototype.whoami = function () {
            return this.config.iam || 'coder';
        };
        return MyAgent;
    }(Agent_1.default));
    mocha_1.it('Should work directly', function () {
        var agent = new MyAgent({
            molecule: {},
        });
        chai_1.assert.equal('coder', agent.whoami());
    });
    mocha_1.it('Should work with factory', function () {
        var factory = MyAgent.factory({
            iam: 'code',
        });
        var agent = factory({});
        chai_1.assert.equal('code', agent.whoami());
    });
    mocha_1.it('Should properly get the molecule', function () {
        var factory = MyAgent.factory({
            iam: 'code',
        });
        var agent = factory({
            name: 'dummy',
        });
        chai_1.assert.equal('dummy', agent.molecule.name);
    });
    mocha_1.it('Should be able to get the agent from the molecule through getAgent()', function () {
        var molecule = new Molecule_1.default({
            agents: {
                first: MyAgent.factory(),
                second: MyAgent.factory(),
            },
        });
        var second = molecule.getAgent('first').getAgent('second');
        chai_1.assert.isObject(second);
    });
    mocha_1.it('Event emissions', function (done) {
        var agent = new MyAgent({
            molecule: {},
        });
        var fn = function () { return done('Error'); };
        agent.on('do-not-throw', fn);
        agent.off('do-not-throw', fn);
        agent.on('done', function () { return done(); });
        agent.emit('do-not-throw');
        agent.emit('done');
    });
});
//# sourceMappingURL=Agent.js.map